summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--lisp/x-dnd.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/lisp/x-dnd.el b/lisp/x-dnd.el
index 3b15eb432e3..52f7340657a 100644
--- a/lisp/x-dnd.el
+++ b/lisp/x-dnd.el
@@ -115,9 +115,9 @@ If the symbol `files', use the OffiX protocol when dropping
files, and the fallback drop method (which is used with programs
like xterm) for text."
:version "29.1"
- :type '(choice (const "Don't use the OffiX protocol for drag-and-drop")
- (const "Only use the OffiX protocol to drop files")
- (const "Use the OffiX protocol for both files and text"))
+ :type '(choice (const :tag "Don't use the OffiX protocol for drag-and-drop" nil)
+ (const :tag "Only use the OffiX protocol to drop files" files)
+ (const :tag "Use the OffiX protocol for both files and text" t))
:group 'x)
;; Internal variables